Index: trunk/DataCheck/Monitoring/CheckDU.sh
===================================================================
--- trunk/DataCheck/Monitoring/CheckDU.sh	(revision 17616)
+++ trunk/DataCheck/Monitoring/CheckDU.sh	(revision 17617)
@@ -58,6 +58,6 @@
       if [ ${diskusage[3]} -lt $dulimit ] 
       then
-         echo "WARN less than "$dutext" left on "$dir" on node "$HOSTNAME
-         printprocesslog "DISK less than "$dutext" left on "$dir" on node "$HOSTNAME
+         echo "WARN less than "$dutext" left on "$dir" on node "$HOSTNAME" ("${diskusage[3]}")"
+         printprocesslog "DISK less than "$dutext" left on "$dir" on node "$HOSTNAME" ("${diskusage[3]}")"
          df -h $dir
          echo ""
Index: trunk/DataCheck/Transfer/ZipRawData.sh
===================================================================
--- trunk/DataCheck/Transfer/ZipRawData.sh	(revision 17616)
+++ trunk/DataCheck/Transfer/ZipRawData.sh	(revision 17617)
@@ -75,6 +75,6 @@
       if [ ${diskusage[3]} -lt 10000000 ] 
       then
-         echo "WARN less than 10 GB left on /loc_data on data " >> $logfile 2>&1
-         printprocesslog "WARN less than 10 GB left on /loc_data on data "
+         echo "WARN less than 10 GB left on /loc_data on data ("${diskusage[3]}")" >> $logfile 2>&1
+         printprocesslog "WARN less than 10 GB left on /loc_data on data ("${diskusage[3]}")"
          finish
       fi

Index: trunk/DataCheck/QuickLook/Step1.sh
===================================================================
--- trunk/DataCheck/QuickLook/Step1.sh	(revision 17616)
+++ trunk/DataCheck/QuickLook/Step1.sh	(revision 17617)
@@ -81,6 +81,6 @@
    if [ ${diskusage[3]} -lt $disklimitdaq ] 
    then
-      #echo "WARN less than 700 left on /raid10 on node "$HOSTNAME
-      printprocesslog "DISK less than 700 left on /raid10 on node "$HOSTNAME
+      #echo "WARN less than 700 left on /raid10 on node "$HOSTNAME" ("${diskusage[3]}")"
+      printprocesslog "DISK less than 700 left on /raid10 on node "$HOSTNAME" ("${diskusage[3]}")"
       #df -h /raid10
       finish